@@ -1,5 +1,5 @@
 package Graphics::Potrace::Vectorial::Eps;
-$Graphics::Potrace::Vectorial::Eps::VERSION = '0.75';
+$Graphics::Potrace::Vectorial::Eps::VERSION = '0.76';
 # ABSTRACT: Encapsulated Postscript exporter for Graphics::Potrace
 
 use strict;
@@ -10,7 +10,7 @@ use Moo;
 extends 'Graphics::Potrace::Vectorial::Exporter';
 
 sub save {
-   my ($self, $vector) = @_;
+   my $self = shift;
    my $fh = $self->fh();
 
    # Header
@@ -79,7 +79,7 @@ Graphics::Potrace::Vectorial::Eps - Encapsulated Postscript exporter for Graphic
 
 =head1 VERSION
 
-version 0.75
+version 0.76
 
 =head1 DESCRIPTION
 
